@@ -428,10 +428,10 @@ class SignalBackend(Backend):
     def handle_leave_room_request(self, user, room):
         self.logger.info(f"Leave room '{room}' request for user '{user}'")
 
-    def copy_file(self, attachment):
-        self.logger.debug(f"Handling attachemnt {attachment}")
-        path = Path(attachment["storedFilename"])
-        id_ = attachment["id"]
+    def copy_file(self, attachment: JsonAttachmentv0):
+        self.logger.debug(f"Handling attachment {attachment}")
+        path = Path(attachment.storedFilename)
+        id_ = attachment.id
 
         web_dir = Path(self.config["service.web_directory"])
         new_dir = web_dir / id_
@@ -439,7 +439,7 @@ class SignalBackend(Backend):
 
         new_path = new_dir / id_
 
-        content_type = attachment.get("contentType").lower()
+        content_type = attachment.contentType.lower()
         if "jpeg" in content_type:
             new_path = new_path.with_suffix(".jpg")
         elif "gif" in content_type:
